<?php
/* --------------------------------------------------------------
   OvistoLogoFactory.inc.php 2018-01-31
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class OvistoLogoFactory
 *
 * @category   Core
 * @package    Ovisto
 * @subpackage Factories
 */
class OvistoLogoFactory
{
    /**
     * @var OvistoLogoStorageWriterInterface $logoStorageWriter
     */
    protected $logoStorageWriter;
    
    
    /**
     * OvistoLogoFactory constructor.
     *
     * @param OvistoLogoStorageWriterInterface $logoStorageWriter
     */
    public function __construct(OvistoLogoStorageWriterInterface $logoStorageWriter)
    {
        $this->logoStorageWriter = $logoStorageWriter;
    }
    
    
    /**
     * Creates an empty logo instance representing the absence of the logo in the filesystem.
     *
     * @return OvistoLogo
     */
    public function createEmptyLogo()
    {
        return MainFactory::create(OvistoLogo::class, $this->logoStorageWriter, new StringType(''), new StringType(''));
    }
    
    
    /**
     * Creates a logo instance from a given file path.
     *
     * @param StringType $logoUrl
     * @param StringType $logoPath
     *
     * @return OvistoLogo
     */
    public function createLogo(StringType $logoUrl, StringType $logoPath)
    {
        return MainFactory::create(OvistoLogo::class, $this->logoStorageWriter, $logoUrl, $logoPath);
    }
}